botApi class

Constructors

botApi(RpcClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAgent(ClientContext? ctx, CreateAgentReq request) Future<CreateAgentResp>
deleteAgent(ClientContext? ctx, DeleteAgentReq request) Future<DeleteAgentResp>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pageFindAgent(ClientContext? ctx, PageFindAgentReq request) Future<PageFindAgentResp>
sendBotMessage(ClientContext? ctx, SendBotMessageReq request) Future<SendBotMessageResp>
toString() String
A string representation of this object.
inherited
updateAgent(ClientContext? ctx, UpdateAgentReq request) Future<UpdateAgentResp>

Operators

operator ==(Object other) bool
The equality operator.
inherited