MsgData class
- Available extensions
Constructors
-
MsgData({String? sendID, String? recvID, String? groupID, String? clientMsgID, String? serverMsgID, int? senderPlatformID, String? senderNickname, String? senderFaceURL, int? sessionType, int? msgFrom, int? contentType, List<
int> ? content, Int64? seq, Int64? sendTime, Int64? createTime, int? status, bool? isRead, Iterable<MapEntry< ? options, OfflinePushInfo? offlinePushInfo, Iterable<String, bool> >String> ? atUserIDList, String? attachedInfo, String? ex}) -
factory
-
MsgData.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- MsgData.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- attachedInfo ↔ String
-
getter/setter pair
-
atUserIDList
→ PbList<
String> -
no setter
- clientMsgID ↔ String
-
getter/setter pair
-
content
↔ List<
int> -
getter/setter pair
- contentType ↔ int
-
getter/setter pair
- createTime ↔ Int64
-
getter/setter pair
- ex ↔ String
-
getter/setter pair
- groupID ↔ String
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - isRead ↔ bool
-
getter/setter pair
- msgFrom ↔ int
-
getter/setter pair
- offlinePushInfo ↔ OfflinePushInfo
-
getter/setter pair
-
options
→ PbMap<
String, bool> -
no setter
- recvID ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderFaceURL ↔ String
-
getter/setter pair
- senderNickname ↔ String
-
getter/setter pair
- senderPlatformID ↔ int
-
getter/setter pair
- sendID ↔ String
-
getter/setter pair
- sendTime ↔ Int64
-
getter/setter pair
- seq ↔ Int64
-
getter/setter pair
- serverMsgID ↔ String
-
getter/setter pair
- sessionType ↔ int
-
getter/setter pair
- status ↔ int
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAttachedInfo(
) → void -
clearClientMsgID(
) → void -
clearContent(
) → void -
clearContentType(
) → void -
clearCreateTime(
) → void -
clearEx(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearGroupID(
) → void -
clearIsRead(
) → void -
clearMsgFrom(
) → void -
clearOfflinePushInfo(
) → void -
clearRecvID(
) → void -
clearSenderFaceURL(
) → void -
clearSenderNickname(
) → void -
clearSenderPlatformID(
) → void -
clearSendID(
) → void -
clearSendTime(
) → void -
clearSeq(
) → void -
clearServerMsgID(
) → void -
clearSessionType(
) → void -
clearStatus(
) → void -
clone(
) → MsgData - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(MsgData)) → MsgData -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → MsgData - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureOfflinePushInfo(
) → OfflinePushInfo -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAttachedInfo(
) → bool -
hasClientMsgID(
) → bool -
hasContent(
) → bool -
hasContentType(
) → bool -
hasCreateTime(
) → bool -
hasEx(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasGroupID(
) → bool -
hasIsRead(
) → bool -
hasMsgFrom(
) → bool -
hasOfflinePushInfo(
) → bool -
hasRecvID(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSenderFaceURL(
) → bool -
hasSenderNickname(
) → bool -
hasSenderPlatformID(
) → bool -
hasSendID(
) → bool -
hasSendTime(
) → bool -
hasSeq(
) → bool -
hasServerMsgID(
) → bool -
hasSessionType(
) → bool -
hasStatus(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → MsgData -
getDefault(
) → MsgData