botServiceBase class abstract
Constructors
Properties
Methods
-
createAgent(
ServerContext ctx, CreateAgentReq request) → Future< CreateAgentResp> -
createRequest(
String methodName) → GeneratedMessage - Creates a message object that can deserialize a request.
-
deleteAgent(
ServerContext ctx, DeleteAgentReq request) → Future< DeleteAgentResp> -
handleCall(
ServerContext ctx, String methodName, GeneratedMessage request) → Future< GeneratedMessage> - Dispatches the call. The request object should come from createRequest.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pageFindAgent(
ServerContext ctx, PageFindAgentReq request) → Future< PageFindAgentResp> -
sendBotMessage(
ServerContext ctx, SendBotMessageReq request) → Future< SendBotMessageResp> -
toString(
) → String -
A string representation of this object.
inherited
-
updateAgent(
ServerContext ctx, UpdateAgentReq request) → Future< UpdateAgentResp>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited